@@ -1,15 +1,16 @@
 """Main module."""
 
-import asyncio
-import random
 import re
-import codecs
+from asyncio import wait_for
+from asyncio import get_event_loop
+from random import randint
+from codecs import lookup 
 from functools import partial
 from json import dumps
 from json import loads
 from ssl import SSLContext
-import gzip
-import zlib
+from gzip import decompress as gzip_decompress
+from zlib import decompress as zlib_decompress
 
 from io import IOBase
 from os.path import basename
@@ -84,7 +85,7 @@ class HttpHeaders(CaseInsensitiveDict):
     @staticmethod
     def _clear_line(line: bytes):
         """Clear readed line."""
-        return line.rstrip().split(b': ')
+        return line.rstrip().split(b': ', 1)
 
 
 #: Headers
@@ -145,9 +146,9 @@ class HttpResponse:
     def _set_body(self, data):
         """Set body."""
         if self.compressed == b'gzip':
-            self.body += gzip.decompress(data)
+            self.body += gzip_decompress(data)
         elif self.compressed == b'deflate':
-            self.body += zlib.decompress(data)
+            self.body += zlib_decompress(data)
         else:
             self.body += data
 
@@ -161,7 +162,7 @@ class HttpResponse:
 
         if encoding:
             try:
-                codecs.lookup(encoding)
+                lookup(encoding)
             except LookupError:
                 encoding = ''
 
@@ -226,8 +227,9 @@ def _get_header_data(url: ParseResult,
 
     if params:
         query = urlencode(params)
-        path += '%s' % query if '?' in path else '?%s' % query
-    get_base = '%s %s HTTP/1.1%s' % (method.upper(), path, _NEW_LINE)
+        path += f'{query}' if '?' in path else f'?{query}'
+    uppercase_method = method.upper()
+    get_base = f'{uppercase_method} {path} HTTP/1.1{_NEW_LINE}'
 
     port = url.port or (443 if url.scheme == 'https' else 80)
     hostname = url.hostname
@@ -242,18 +244,17 @@ def _get_header_data(url: ParseResult,
             ':authority': hostname.split(':')[0],
             ':scheme': 'https',
             ':path': path,
-            'user-agent': 'aioload/%s' % VERSION
+            'user-agent': f'aioload/{VERSION}'
         })
     else:
         headers_base.update({
             'HOST': hostname,
             'Connection': 'keep-alive',
-            'User-Agent': 'aioload/%s' % VERSION
+            'User-Agent': f'aioload/{VERSION}'
         })
 
     if multipart:
-        headers_base[
-            'Content-Type'] = 'multipart/form-data; boundary="%s"' % boundary
+        headers_base['Content-Type'] = f'multipart/form-data; boundary="{boundary}"'
 
     if headers:
         headers_base.update(headers)
@@ -262,7 +263,7 @@ def _get_header_data(url: ParseResult,
         return headers_base
 
     for key, data in headers_base.items():
-        get_base += '%s: %s%s' % (key, data, _NEW_LINE)
+        get_base += f'{key}: {data}{_NEW_LINE}'
     return (get_base + _NEW_LINE).encode()
 
 
@@ -329,7 +330,7 @@ async def _send_multipart(data: Dict[str, str],
     to_send = b''
     for key, val in data.items():
         # write --boundary + field
-        to_send += ('--%s%s' % (boundary, _NEW_LINE)).encode()
+        to_send += (f'--{boundary}{_NEW_LINE}').encode()
 
         if isinstance(val, IOBase):
             # TODO: Utility to accept files with multipart metadata
@@ -342,7 +343,7 @@ async def _send_multipart(data: Dict[str, str],
             to_send += to_write.encode()
 
             # read and write chunks
-            loop = asyncio.get_event_loop()
+            loop = get_event_loop()
             while True:
                 data = await loop.run_in_executor(None, val.read, chunk_size)
                 if not data:
@@ -351,12 +352,11 @@ async def _send_multipart(data: Dict[str, str],
             val.close()
 
         else:
-            to_send += ('Content-Disposition: form-data; name="%s"%s%s' %
-                        (key, _NEW_LINE, _NEW_LINE)).encode()
+            to_send += (f'Content-Disposition: form-data; name="{key}"{_NEW_LINE}{_NEW_LINE}').encode()
             to_send += val.encode() + _NEW_LINE.encode()
 
     # write --boundary-- for finish
-    to_send += ('--%s--' % boundary).encode()
+    to_send += (f'--{boundary}--').encode()
     _add_header(headers, 'Content-Length', str(len(to_send)))
     return to_send
 
@@ -392,7 +392,7 @@ async def _do_request(urlparsed: ParseResult,
 
         # get response code and version
         try:
-            response._set_response_initial(await asyncio.wait_for(
+            response._set_response_initial(await wait_for(
                 connection.reader.readline(),
                 (timeouts or connector.timeouts).sock_read))
         except TimeoutException:
@@ -402,7 +402,7 @@ async def _do_request(urlparsed: ParseResult,
         # reading headers
         while True:
             res_data = await connection.reader.readline()
-            if b': ' not in res_data:
+            if b': ' not in res_data and b':' not in res_data:
                 break
             response._set_header(*HttpHeaders._clear_line(res_data))
 
@@ -642,7 +642,7 @@ class HTTPClient:
         elif multipart:
             if not isinstance(data, dict):
                 raise ValueError('data should be dict')
-            boundary = 'boundary-%d' % random.randint(10**8, 10**9)
+            boundary = 'boundary-%d' % randint(10**8, 10**9)
             body = await _send_multipart(data, boundary, headers)
 
         max_redirects = 30
@@ -655,7 +655,7 @@ class HTTPClient:
                                    multipart=multipart,
                                    boundary=boundary)
             try:
-                response = await asyncio.wait_for(
+                response = await wait_for(
                     _do_request(urlparsed, headers_data, self.connector, body,
                                 verify, ssl, timeouts, http2),
                     timeout=(timeouts
@@ -693,7 +693,7 @@ class HTTPClient:
         This is useful when doing safe shutdown of a process.
         """
         try:
-            return await asyncio.wait_for(
+            return await wait_for(
                 self.connector.wait_free_pool(), timeout)
         except TimeoutException:
             return False
